.. default-domain:: py

================================================
django-tables2 - An app for creating HTML tables
================================================

Its features include:

- Any iterable can be a data-source, but special support for Django querysets is included.
- The builtin UI does not rely on JavaScript.
- Support for automatic table generation based on a Django model.
- Supports custom column functionality via subclassing.
- Pagination.
- Column based table sorting.
- Template tag to enable trivial rendering to HTML.
- Generic view mixin.


About the app:

- `Available on pypi <https://pypi.python.org/pypi/django-tables2>`_
- Tested with python 2.7, 3.3, 3.4, 3.5 and Django 1.8, 1.9, `Travis CI <https://travis-ci.org/bradleyayers/django-tables2>`_
- `Documentation on readthedocs.org <https://django-tables2.readthedocs.io/en/latest/>`_
- `Bug tracker <http://github.com/bradleyayers/django-tables2/issues>`_


Table of contents
-----------------

.. toctree::
    pages/getting-started
    pages/customizing
    pages/reference
    pages/faq
    pages/upgrade-changelog
    pages/glossary
